@@ -3,12 +3,12 @@ use warnings;
 use strict;
 use Sys::Statistics::Linux;
 
-$|++;
+$| = 1;
 
 my $header  = 20;
 my $average = 1;
 my $tcolumn = 10;
-my $dcolumn = 14;
+my $dcolumn = 10;
 my $options = { DiskStats => 1 };
 my @order   = qw(major minor rdreq rdbyt wrtreq wrtbyt ttreq ttbyt);
 my $lxs     = Sys::Statistics::Linux->new( $options );
@@ -20,7 +20,7 @@ while (1) {
 
    if ($h == $header) {
       printf "%${tcolumn}s", $_ for ('date', 'time');
-      printf "%${dcolumn}s", $_ for ('disk', @order);
+      printf "%${dcolumn}s", $_ for ('iface', @order);
       print "\n";
    }
 
@@ -28,9 +28,9 @@ while (1) {
 
    foreach my $device (keys %{$stats->{DiskStats}}) {
       my $dstat = $stats->{DiskStats}->{$device};
-      printf "%${tcolumn}s", $_ for ($date, $time);
-      printf "%${dcolumn}s", substr($device, 0, 12);
-      printf "%${dcolumn}s", $dstat->{$_} for @order;
+      printf "%${dcolumn}s", $_ for ($date, $time);
+      printf "%${tcolumn}s", $device;
+      printf "%${tcolumn}s", $dstat->{$_} for @order;
       print "\n";
    }
    $h = $header if --$h == 0;
