@@ -3,17 +3,19 @@ use warnings;
 use strict;
 use Sys::Statistics::Linux;
 
-$|++;
+$| = 1;
 
-my $header   = 20;
-my $interval = 1;
-my $dcolumn  = 10;
-my $tcolumn  = 10;
-my @order    = qw(avg_1 avg_5 avg_15);
-my $h        = $header;
-my $lxs      = Sys::Statistics::Linux->new(LoadAVG => 1);
+my $header  = 20;
+my $average = 1;
+my $dcolumn = 10;
+my $tcolumn = 10;
+my $options = { LoadAVG => 1 };
+my @order   = qw(avg_1 avg_5 avg_15);
+my $lxs     = Sys::Statistics::Linux->new( $options );
+my $h       = $header;
 
 while (1) {
+   sleep($average);
    my $stats = $lxs->get;
 
    if ($h == $header) {
@@ -30,5 +32,5 @@ while (1) {
    print "\n";
 
    $h = $header if --$h == 0;
-   sleep $interval;
 }
+
