@@ -3,7 +3,7 @@ use warnings;
 use strict;
 use Sys::Statistics::Linux;
 
-$|++;
+$| = 1;
 
 my $header  = 20;
 my $average = 1;
@@ -13,22 +13,22 @@ my $options = { Processes => 1 };
 
 # you need a very very width screen for this output :-)
 
-my @order = qw(
-   ppid owner pgrp state session ttynr minflt cminflt mayflt cmayflt
+my @order   = qw(
+   pid ppid owner pgrp state session ttynr minflt cminflt mayflt cmayflt
    stime utime cstime cutime prior nice sttime actime vsize nswap cnswap
    cpu size resident share trs drs lrs dtp cmd cmdline
 );
 
-my $lxs = Sys::Statistics::Linux->new( $options );
-my $h   = $header;
+my $lxs     = Sys::Statistics::Linux->new( $options );
+my $h       = $header;
 
 while (1) {
    sleep($average);
    my $stats = $lxs->get;
 
    if ($h == $header) {
-      printf "%${tcolumn}s", $_ for ('date', 'time', 'pid');
-      printf "%${dcolumn}s", $_ for @order;
+      printf "%${tcolumn}s", $_ for ('date', 'time');
+      printf "%${dcolumn}s", $_ for ('iface', @order);
       print "\n";
    }
 
